@@ -115,7 +115,7 @@ public:
 
 class KVILIB_API KviIrcUserDataBase : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviIrcUserDataBase();
