@@ -171,7 +171,7 @@ bool KviHttpRequest::start()
 	if(kvi_isValidStringIp(m_url.host().ptr()))
 	{
 		m_szIp = m_url.host();
-		TQTimer::singleShot(10,this,TQT_SLOT(haveServerIp()));
+		TQTimer::singleShot(10,this,TQ_SLOT(haveServerIp()));
 		return true;
 	}
 
@@ -181,7 +181,7 @@ bool KviHttpRequest::start()
 bool KviHttpRequest::startDnsLookup()
 {
 	m_pDns = new KviDns();
-	connect(m_pDns,TQT_SIGNAL(lookupDone(KviDns *)),this,TQT_SLOT(dnsLookupDone(KviDns *)));
+	connect(m_pDns,TQ_SIGNAL(lookupDone(KviDns *)),this,TQ_SLOT(dnsLookupDone(KviDns *)));
 
 	if(!m_pDns->lookup(m_url.host().ptr(),KviDns::IpV4))
 	{
