@@ -22,14 +22,14 @@
 //   Inc. ,51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 //
 
-#include <ktoolbar.h>
+#include <tdetoolbar.h>
 
 #include "kvi_tal_toolbardocktype.h"
 
-class KVILIB_API KviTalToolBar : public KToolBar
+class KVILIB_API KviTalToolBar : public TDEToolBar
 {
-	Q_OBJECT
-  TQ_OBJECT
+	TQ_OBJECT
+  
 public:
 	KviTalToolBar(const TQString &label,TQMainWindow *w,TQT_TOOLBARDOCK_TYPE dock = TQT_DOCK_TOP,bool bNewLine = false,const char * nam = 0);
 	~KviTalToolBar();
