@@ -90,8 +90,8 @@ void KviFileTransferManager::invokeTransferWindow(KviWindow * pWnd,bool bCreateM
 	{
 		KviPointerHashTable<TQString,TQVariant> d(7,false);
 		d.setAutoDelete(true);
-		d.replace("bCreateMinimized",new TQVariant(bCreateMinimized,0));
-		d.replace("bNoRaise",new TQVariant(bNoRaise,0));
+		d.replace("bCreateMinimized",new TQVariant(bCreateMinimized));
+		d.replace("bNoRaise",new TQVariant(bNoRaise));
 
 		KviModuleExtensionManager::instance()->allocateExtension(
 				"tool",
