@@ -47,12 +47,7 @@
 	#include "kvi_xlib.h" // XBell : THIS SHOULD BE INCLUDED AS LAST!
 	#include <unistd.h>   // for usleep();
 
-	#ifdef COMPILE_USE_QT4
-		#include <tqx11info_x11.h>
-		#define get_xdisplay QX11Info::display
-	#else
 		#define get_xdisplay tqt_xdisplay
-	#endif
 
 #endif
 
