@@ -87,7 +87,7 @@ protected:
 
 class KVIRC_API KviKvsTimerManager : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 protected: // it only can be created and destroyed by KviKvsTimerManager::init()/done()
 	KviKvsTimerManager();
