@@ -31,7 +31,7 @@
 
 class KVIRC_API KviMexServerImport : public TQObject, public KviModuleExtension
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviMexServerImport(KviModuleExtensionDescriptor * d);
