@@ -72,11 +72,7 @@
 //#include "kvi_iconmanager.h"
 #include <tqdatetime.h>
 
-#ifdef COMPILE_USE_QT4
-	#include <TQTextDocument>
-#else
 	#include <tqstylesheet.h>
-#endif
 
 extern KviNickServRuleSet * g_pNickServRuleSet;
 
@@ -916,11 +912,7 @@ void KviServerParser::parseLiteralPrivmsg(KviIrcMessage *msg)
 					{
 						// don't send the message to the notifier twice
 						iFlags |= KviConsole::NoNotifier;
-						#ifdef COMPILE_USE_QT4
-							TQString szMsg = TQt::escape(szMsgText); 
-						#else
 							TQString szMsg = TQStyleSheet::escape(szMsgText);
-						#endif
 						//tqDebug("kvi_sp_literal.cpp:908 debug: %s",szMsg.data());
 						g_pApp->notifierMessage(query,KVI_SMALLICON_QUERYPRIVMSG,szMsg,1800);
 					}
@@ -1274,11 +1266,7 @@ void KviServerParser::parseLiteralNotice(KviIrcMessage *msg)
 					{
 						// don't send the message twice to the notifier
 						iFlags |= KviConsole::NoNotifier;
-						#ifdef COMPILE_USE_QT4
-							TQString szMsg = TQt::escape(szMsgText); 
-						#else
 							TQString szMsg = TQStyleSheet::escape(szMsgText);
-						#endif
 						//tqDebug("kvi_sp_literal.cpp:908 debug: %s",szMsg.data());
 						g_pApp->notifierMessage(query,KVI_SMALLICON_QUERYNOTICE,szMsg,1800);
 					}
