@@ -33,7 +33,7 @@ class KviIrcConnection;
 
 class KviAsyncAvatarSelectionDialog : public TQDialog
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviAsyncAvatarSelectionDialog(TQWidget * par,const TQString &szInitialPath,KviIrcConnection * c);
