@@ -102,7 +102,7 @@ class TQSlider;
 
 class KviDccVoice : public KviDccWindow
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviDccVoice(KviFrame *pFrm,KviDccDescriptor * dcc,const char * name);
