@@ -34,7 +34,7 @@ class TQLineEdit;
 
 class KviHelpWidget : public TQWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviHelpWidget(TQWidget *par,KviFrame * lpFrm,bool bIsStandalone = false);
