@@ -41,7 +41,7 @@ class TQToolButton;
 
 class KviGeneralOptionsFrontWidget : public KviOptionsWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviGeneralOptionsFrontWidget(TQWidget *parent,const TQString &szText);
@@ -66,7 +66,7 @@ protected:
 
 class KviOptionsDialog : public TQDialog
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviOptionsDialog(TQWidget * par,const TQString &szGroup); 
