@@ -31,7 +31,7 @@
 
 class KviUParserOptionsWidget : public KviOptionsWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviUParserOptionsWidget(TQWidget * parent);
