@@ -34,7 +34,7 @@
 
 class KviUserListLookOptionsWidget : public KviOptionsWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviUserListLookOptionsWidget(TQWidget * parent);
@@ -51,7 +51,7 @@ public:
 
 class KviUserListLookBackgroundOptionsWidget : public KviOptionsWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviUserListLookBackgroundOptionsWidget(TQWidget * parent);
@@ -73,7 +73,7 @@ public:
 
 class KviUserListLookForegroundOptionsWidget : public KviOptionsWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviUserListLookForegroundOptionsWidget(TQWidget * parent);
@@ -90,7 +90,7 @@ public:
 
 class KviUserListGridOptionsWidget : public KviOptionsWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviUserListGridOptionsWidget(TQWidget * parent);
@@ -109,7 +109,7 @@ public:
 
 class KviUserListFeaturesOptionsWidget : public KviOptionsWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviUserListFeaturesOptionsWidget(TQWidget * parent);
