@@ -300,7 +300,7 @@ KviSetupWizard::KviSetupWizard()
 #endif
 	// Pragma: Unused, takes only space.
 	//m_pDirRestore = new TQRadioButton(__tr2qs("Restore from backup archive"),m_pDirButtonGroup);
-	//m_pDirRestore->setEnabled(FALSE);
+	//m_pDirRestore->setEnabled(false);
 	
 	//l = new TQLabel(m_pDirectory->m_pVBox,"<b> </b>");
 
@@ -538,9 +538,9 @@ KviSetupWizard::KviSetupWizard()
 	*/
 /*
 	m_pServersLoadConfig = new TQRadioButton(__tr2qs("Use server config"),m_pServersButtonGroup);
-	m_pServersLoadConfig->setEnabled(FALSE);
+	m_pServersLoadConfig->setEnabled(false);
 	m_pServerConfigSelector = new KviFileSelector(m_pServersButtonGroup,__tr2qs("Config file:"),&m_szServerConfigFile,true);
-	m_pServerConfigSelector->setEnabled(FALSE);
+	m_pServerConfigSelector->setEnabled(false);
 */
 	/*
 	m_pServersChooseFromList->toggle();
@@ -557,7 +557,7 @@ KviSetupWizard::KviSetupWizard()
 	{
 		KviConfig cfg(szTmp,KviConfig::Read);
 		cfg.setGroup("Setup");
-		if(cfg.readBoolEntry("hideServerList",FALSE))
+		if(cfg.readBoolEntry("hideServerList",false))
 		{
 			//setPageEnabled(m_pServers,false);
 			//setFinishEnabled(m_pIdentity,true);
@@ -1095,12 +1095,12 @@ void KviSetupWizard::accept()
 			
 			if(m_pServersSpecifyManually->isOn())
 			{
-				KVI_OPTION_BOOL(KviOption_boolShowServersConnectDialogOnStart) = FALSE;
+				KVI_OPTION_BOOL(KviOption_boolShowServersConnectDialogOnStart) = false;
 				szHost = m_szServerHost;
 				uPort=m_uServerPort;
 			} else if(m_pServersOpenIrcUrl->isOn())
 			{
-				KVI_OPTION_BOOL(KviOption_boolShowServersConnectDialogOnStart) = FALSE;
+				KVI_OPTION_BOOL(KviOption_boolShowServersConnectDialogOnStart) = false;
 				szUrl=m_szServerUrl;
 			}
 			*/
