@@ -31,7 +31,7 @@
 
 class SPasteController : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     SPasteController(KviWindow * w,int id);
