@@ -9,7 +9,7 @@ KviTorrentStatusBarApplet::KviTorrentStatusBarApplet(KviStatusBar *parent, KviSt
 {
 	TQTimer *timer = new TQTimer(this);
 	connect(timer, TQ_SIGNAL(timeout()), this, TQ_SLOT(update()));
-	timer->start(250, FALSE);
+	timer->start(250, false);
 //	updateDisplay();
 //
 	setText("torrent client");
